diff dw.h @ 15:81833f25b1aa

Added new Dynamic Windows build information to the DWEnv struct. It reports version numbers and build time/date.
author bsmith@81767d24-ef19-dc11-ae90-00e081727c95
date Thu, 12 Jul 2001 20:31:26 +0000
parents 176cee043f1b
children 6a246b3bb14f
line wrap: on
line diff
--- a/dw.h	Wed Jul 11 21:57:56 2001 +0000
+++ b/dw.h	Thu Jul 12 20:31:26 2001 +0000
@@ -3,6 +3,11 @@
 #ifndef _H_DW
 #define _H_DW
 
+/* Dynamic Windows version numbers */
+#define DW_MAJOR_VERSION 0
+#define DW_MINOR_VERSION 5
+#define DW_SUB_VERSION 0
+
 #if defined(__OS2__) || defined(__WIN32__) || defined(WINNT) || defined(__EMX__)
 /* OS/2 or Windows */
 
@@ -486,10 +491,12 @@
 #endif
 
 typedef struct _dwenv {
-    /* Operating System Name */
-	char osName[30];
+	/* Operating System Name and DW Build Date/Time */
+	char osName[30], buildDate[30], buildTime[30];
 	/* Versions and builds */
 	short MajorVersion, MinorVersion, MajorBuild, MinorBuild;
+	/* Dynamic Window version */
+	short DWMajorVersion, DWMinorVersion, DWSubVersion;
 } DWEnv;